package org.nst.pasientlink.authenticator.admin;

/**
 * <p>Title: PronouncablePassword </p>
 * <p>Description: PronouncablePassword, adapted from GPW (see below), which again is
 * based on techniqes described in FIPS 181 (http://www.itl.nist.gov/fipspubs/fip181.htm)
 * GPW - Generate pronounceable passwords
 * This program uses statistics on the frequency of three-letter sequences
 * in English to generate passwords.  The statistics are
 * generated from your dictionary by the program loadtris.v
 *
 * See www.multicians.org/thvv/gpw.html for history and info.
 * Tom Van Vleck
 *
 * THVV 06/01/94 Coded
 * THVV 04/14/96 converted to Java
 * THVV 07/30/97 fixed for Netscape 4.0
 */

import java.util.Random;
import java.security.*;

public class PronouncablePassword {
   private static GpwData data = null;
   final static String alphabet = "abcdefghijklmnopqrstuvwxyz";
   private static final String SECURE_RANDOM_ALGORITHM = "SHA1PRNG";
   private static final String SECURE_RANDOM_PROVIDER = "SUN";
   private SecureRandom randomizer;

   public PronouncablePassword() {
      if(data == null) {
         data = new GpwData();
      }
      try {
         this.randomizer = SecureRandom.getInstance(SECURE_RANDOM_ALGORITHM, SECURE_RANDOM_PROVIDER);
      }
      catch (NoSuchProviderException e) {
      }
      catch (NoSuchAlgorithmException e) {
      }

   }

   /**
    *
    */

   public static void main(String[] args) {
      PronouncablePassword me  = new PronouncablePassword();
      System.out.println(me.nextPassword());
   }

   public String nextPassword() {
      int bvpwl = 10;
      int pwl = 6;
      int npw = 10;
    int c1, c2, c3;
    long sum = 0;
    int nchar;
    long ranno;
    int pwnum;
    double pik;
    StringBuffer password;

    // Pick a random starting point.
   password = new StringBuffer(pwl);
   pik = randomizer.nextDouble(); // random number [0,1]
   ranno = (long)(pik * data.getSigma()); // weight by sum of frequencies
   sum = 0;
   for (c1=0; c1 < 26; c1++) {
      for (c2=0; c2 < 26; c2++) {
        for (c3=0; c3 < 26; c3++) {
          sum += data.get(c1, c2, c3);
          if (sum > ranno) {
            password.append(alphabet.charAt(c1));
            password.append(alphabet.charAt(c2));
            password.append(alphabet.charAt(c3));
            c1 = 26; // Found start. Break all 3 loops.
            c2 = 26;
            c3 = 26;
          } // if sum
        } // for c3
      } // for c2
   } // for c1

   // Now do a random walk.
   nchar = 3;
   while (nchar < pwl) {
      c1 = alphabet.indexOf(password.charAt(nchar-2));
      c2 = alphabet.indexOf(password.charAt(nchar-1));
      sum = 0;
      for (c3=0; c3 < 26; c3++)
        sum += data.get(c1, c2, c3);
      if (sum == 0) {
        break;	// exit while loop
      }
      pik = randomizer.nextDouble();
      ranno = (long)(pik * sum);
      sum = 0;
      for (c3=0; c3 < 26; c3++) {
        sum += data.get(c1, c2, c3);
        if (sum > ranno) {
          password.append(alphabet.charAt(c3));
          c3 = 26; // break for loop
        } // if sum
      } // for c3
      nchar ++;
   } // while nchar
   return password.toString() + randomizer.nextInt(99);
  } // generate()
} // GpwWindow

// ================================================================

class GpwData {
  static short tris[][][] = null;
  static long sigma[] = null; // 125729

  GpwData () {
    int c1, c2, c3;
    tris = new short[26][26][26];
    sigma = new long[1];
    GpwDataInit1.fill(this); // Break into two classes for NS 4.0
    GpwDataInit2.fill(this); // Break into two classes for NS 4.0

    for (c1=0; c1 < 26; c1++) {
      for (c2=0; c2 < 26; c2++) {
         for (c3=0; c3 < 26; c3++) {
           sigma[0] += (long) tris[c1][c2][c3];
         } // for c3
      } // for c2
    } // for c1
  } // constructor

  void set(int x1, int x2, int x3, short v) {
    tris[x1][x2][x3] = v;
  } // set()

  long get(int x1, int x2, int x3) {
    return (long) tris[x1][x2][x3];
  } // get()

  long getSigma() {
    return sigma[0];
  } // get()
} // GpwData

// ================================================================

class GpwDataInit1 {

  final static short tris1[][][] = {{ /* [13][26][26] */
/* A A */ {11, 83, 1, 561, 106, 62, 172, 22, 17, 3, 359, 713, 70, 568, 7, 240, 0, 825, 329, 573, 4, 81, 0, 0, 0, 0, },
/* A B */ {152, 87, 1, 5, 284, 1, 0, 2, 121, 1, 1, 76, 0, 2, 164, 0, 0, 123, 47, 0, 45, 0, 3, 0, 31, 0, },
/* A C */ {4, 0, 3, 0, 20, 0, 0, 28, 12, 0, 32, 2, 0, 0, 12, 0, 1, 0, 0, 9, 1, 0, 0, 0, 0, 0, },
/* A D */ {69, 12, 0, 70, 662, 5, 39, 10, 283, 22, 13, 32, 110, 20, 61, 5, 0, 104, 195, 7, 8, 61, 1, 0, 19, 0, },
/* A E */ {1, 4, 0, 23, 1, 4, 14, 0, 0, 0, 11, 93, 2, 80, 0, 13, 0, 1679, 41, 53, 0, 11, 0, 0, 0, 0, },
/* A F */ {31, 2, 2, 1, 45, 180, 2, 1, 262, 19, 1, 24, 1, 7, 81, 1, 0, 51, 28, 277, 6, 1, 0, 0, 5, 0, },
/* A G */ {106, 32, 0, 40, 520, 34, 77, 9, 65, 9, 21, 78, 33, 127, 105, 28, 0, 112, 318, 101, 43, 14, 0, 0, 0, 0, },
/* A H */ {35, 0, 0, 0, 21, 1, 0, 0, 5, 4, 0, 7, 3, 3, 19, 0, 0, 3, 0, 1, 6, 6, 0, 0, 3, 0, },
/* A I */ {5, 1, 2, 23, 8, 5, 3, 2, 1, 0, 11, 16, 5, 64, 0, 2, 0, 18, 49, 12, 0, 5, 2, 1, 0, 0, },
/* A J */ {15, 0, 0, 3, 9, 0, 0, 0, 0, 0, 0, 0, 0, 0, 21, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* A K */ {99, 19, 0, 10, 550, 19, 40, 24, 65, 18, 563, 63, 8, 36, 107, 16, 0, 94, 666, 1066, 66, 50, 0, 0, 3, 0, },
/* A L */ {271, 141, 8, 267, 951, 153, 457, 39, 730, 79, 270, 1090, 147, 31, 172, 130, 1, 70, 401, 420, 140, 275, 0, 0, 111, 1, },
/* A M */ {313, 185, 0, 25, 449, 225, 15, 17, 231, 2, 35, 205, 460, 81, 58, 322, 0, 27, 136, 93, 24, 69, 1, 0, 4, 0, },
/* A N */ {275, 48, 27, 2668, 558, 37, 1328, 23, 392, 36, 513, 269, 34, 1459, 106, 14, 0, 15, 1338, 1012, 43, 46, 0, 0, 8, 6, },
/* A O */ {0, 0, 0, 0, 6, 1, 1, 0, 2, 0, 1, 2, 5, 0, 0, 8, 0, 10, 7, 4, 0, 2, 0, 0, 0, 0, },
/* A P */ {91, 0, 2, 2, 288, 1, 1, 3, 221, 2, 0, 16, 1, 56, 83, 501, 0, 51, 258, 43, 11, 0, 0, 0, 6, 0, },
/* A Q */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 4, 0, 0, 0, 0, 0, },
/* A R */ {445, 952, 7, 468, 695, 47, 203, 31, 529, 6, 572, 111, 327, 461, 84, 63, 0, 146, 493, 934, 23, 170, 4, 5, 18, 2, },
/* A S */ {73, 22, 13, 3, 449, 26, 3, 15, 258, 1662, 518, 30, 30, 42, 35, 65, 0, 9, 1158, 772, 35, 8, 1, 0, 38, 0, },
/* A T */ {664, 52, 4, 7, 937, 62, 11, 34, 496, 9, 43, 65, 36, 158, 581, 26, 0, 188, 323, 1059, 268, 23, 0, 0, 13, 0, },
/* A U */ {0, 10, 3, 61, 43, 7, 106, 3, 3, 2, 71, 25, 23, 16, 1, 14, 0, 98, 266, 200, 0, 26, 0, 6, 0, 2, },
/* A V */ {111, 80, 0, 231, 399, 74, 209, 92, 250, 0, 60, 207, 33, 182, 41, 21, 0, 73, 342, 137, 6, 54, 0, 0, 3, 0, },
/* A W */ {8, 1, 0, 0, 0, 0, 0, 0, 2, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* A X */ {0, 0, 0, 0, 1, 0, 0, 0, 9, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 0, },
/* A Y */ {6, 2, 0, 1, 6, 1, 1, 0, 4, 0, 0, 3, 2, 0, 5, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, },
/* A Z */ {4, 0, 0, 1, 4, 0, 0, 0, 16, 0, 0, 0, 0, 0, 11, 0, 0, 0, 0, 2, 1, 0, 0, 0, 1, 21, }},
/* B A */ {{350, 22, 29, 86, 116, 0, 25, 10, 8, 6, 373, 242, 17, 488, 1, 8, 0, 617, 302, 126, 21, 3, 0, 0, 9, 2, },
/* B B */ {7, 0, 1, 0, 216, 1, 0, 2, 7, 0, 2, 7, 5, 0, 7, 1, 0, 8, 8, 3, 7, 2, 0, 0, 25, 0, },
/* B C */ {0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* B D */ {1, 0, 0, 0, 11, 0, 0, 0, 4, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, },
/* B E */ {31, 23, 2, 223, 6, 112, 151, 303, 992, 4, 117, 556, 39, 232, 9, 5, 0, 609, 589, 401, 5, 231, 0, 0, 2, 0, },
/* B F */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, },
/* B G */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* B H */ {4, 0, 1, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, },
/* B I */ {19, 82, 3, 42, 22, 18, 8, 7, 3, 6, 31, 623, 4, 161, 49, 4, 0, 25, 116, 96, 7, 10, 0, 0, 0, 3, },
/* B J */ {5, 0, 0, 0, 63, 0, 0, 0, 0, 0, 0, 0, 0, 0, 119, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, },
/* B K */ {2, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, },
/* B L */ {382, 0, 0, 0, 343, 0, 0, 0, 269, 1, 0, 0, 0, 0, 376, 0, 0, 0, 0, 0, 32, 0, 0, 0, 31, 0, },
/* B M */ {3, 0, 0, 0, 1, 0, 0, 0, 2, 0, 0, 0, 0, 0, 1, 0, 0, 0, 1, 0, 1, 0, 2, 0, 0, 0, },
/* B N */ {0, 0, 0, 0, 17, 0, 0, 0, 1, 0, 0, 0, 0, 0, 2, 1, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, },
/* B O */ {6, 19, 2, 37, 376, 11, 21, 11, 17, 2, 355, 210, 101, 144, 9, 7, 0, 411, 46, 103, 17, 2, 9, 0, 6, 0, },
/* B P */ {1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, },
/* B Q */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* B R */ {337, 0, 0, 2, 439, 0, 0, 0, 248, 0, 0, 0, 0, 0, 408, 0, 0, 0, 0, 1, 662, 0, 0, 0, 178, 0, },
/* B S */ {2, 2, 3, 0, 24, 1, 0, 0, 12, 0, 11, 3, 3, 0, 12, 2, 0, 0, 4, 31, 7, 0, 0, 0, 1, 0, },
/* B T */ {1, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 3, 0, 0, 4, 0, 0, 2, 0, 0, 0, 0, 0, },
/* B U */ {1, 1, 2, 298, 31, 10, 11, 1, 4, 0, 93, 84, 13, 319, 4, 0, 0, 65, 150, 96, 0, 2, 0, 0, 0, 0, },
/* B V */ {0, 0, 0, 0, 2, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* B W */ {0, 0, 0, 0, 2, 0, 0, 0, 1, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* B X */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* B Y */ {11, 14, 1, 31, 10, 16, 466, 5, 5, 1, 13, 16, 10, 2, 3, 15, 0, 96, 39, 38, 2, 6, 0, 0, 0, 0, },
/* B Z */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, }},
/* C A */ {{0, 3, 2, 3, 4, 3, 2, 0, 1, 0, 1, 17, 19, 25, 1, 9, 0, 25, 13, 9, 3, 0, 0, 0, 1, 0, },
/* C B */ {0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, },
/* C C */ {2, 0, 2, 1, 1, 0, 0, 0, 4, 0, 0, 1, 1, 0, 2, 1, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, },
/* C D */ {0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 1, 0, 1, 0, 0, 1, 0, 1, 0, 0, 0, 0, 0, },
/* C E */ {7, 8, 2, 8, 3, 4, 2, 1, 2, 0, 5, 76, 9, 81, 7, 3, 0, 21, 15, 10, 2, 2, 0, 0, 4, 0, },
/* C F */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 0, 0, 0, 0, 0, },
/* C G */ {0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, },
/* C H */ {64, 1, 0, 0, 38, 0, 0, 0, 51, 1, 1, 4, 6, 5, 9, 0, 0, 8, 4, 6, 9, 1, 4, 0, 1, 0, },
/* C I */ {9, 0, 4, 5, 19, 0, 1, 0, 1, 0, 0, 10, 0, 9, 2, 1, 0, 2, 10, 8, 4, 1, 0, 0, 0, 0, },
/* C J */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* C K */ {1, 1, 0, 0, 32, 1, 1, 4, 3, 0, 1, 1, 0, 2, 4, 5, 0, 1, 7, 2, 6, 0, 2, 0, 1, 0, },
/* C L */ {9, 0, 0, 0, 3, 0, 0, 0, 4, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 1, 0, },
/* C M */ {0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, },
/* C N */ {1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, },
/* C O */ {3, 6, 7, 1, 2, 0, 3, 0, 1, 0, 0, 16, 17, 25, 9, 4, 0, 15, 7, 4, 8, 2, 3, 1, 1, 0, },
/* C P */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, },
/* C Q */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, },
/* C R */ {7, 0, 1, 0, 8, 0, 0, 0, 2, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 8, 0, 0, 0, 1, 0, },
/* C S */ {1, 0, 1, 0, 0, 0, 1, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 0, 0, 0, 0, 0, },
/* C T */ {2, 0, 0, 0, 2, 0, 0, 0, 8, 0, 0, 0, 0, 0, 4, 0, 0, 2, 1, 0, 3, 0, 0, 0, 0, 0, },
/* C U */ {2, 3, 0, 0, 1, 0, 0, 0, 0, 0, 0, 4, 1, 0, 0, 6, 0, 8, 1, 4, 0, 0, 0, 1, 0, 0, },
/* C V */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* C W */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, },
/* C X */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* C Y */ {5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 4, 0, 3, 0, 0, 1, 0, 0, 2, 2, 0, 0, 0, 0, 0, 0, },
/* C Z */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, }},
/* D A */ {{65, 15, 1, 17, 22, 14, 533, 8, 4, 0, 68, 335, 145, 395, 3, 8, 0, 200, 43, 629, 16, 31, 0, 0, 0, 0, },
/* D B */ {74, 0, 0, 1, 37, 0, 0, 0, 6, 2, 0, 21, 0, 0, 66, 0, 0, 118, 0, 0, 13, 0, 0, 0, 11, 0, },
/* D C */ {0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, },
/* D D */ {77, 5, 0, 0, 409, 5, 1, 10, 50, 0, 3, 5, 1, 0, 10, 3, 0, 14, 47, 4, 9, 4, 0, 0, 9, 0, },
/* D E */ {42, 183, 8, 56, 14, 177, 65, 56, 44, 4, 333, 1597, 235, 599, 65, 156, 0, 1617, 389, 355, 36, 80, 0, 1, 3, 2, },
/* D F */ {44, 0, 0, 0, 17, 0, 0, 0, 15, 10, 0, 24, 0, 0, 83, 0, 0, 19, 0, 0, 12, 0, 0, 0, 4, 0, },
/* D G */ {51, 1, 0, 0, 13, 0, 0, 0, 32, 15, 0, 1, 0, 0, 2, 0, 0, 25, 0, 0, 8, 0, 0, 0, 1, 0, },
/* D H */ {33, 0, 0, 0, 35, 0, 0, 0, 11, 9, 0, 0, 0, 0, 29, 0, 0, 0, 0, 0, 26, 1, 0, 0, 1, 0, },
/* D I */ {182, 1, 5, 31, 219, 80, 542, 0, 0, 2, 165, 22, 46, 473, 172, 31, 0, 142, 623, 104, 91, 68, 0, 1, 0, 0, },
/* D J */ {8, 0, 0, 0, 42, 0, 0, 0, 1, 0, 0, 0, 0, 0, 7, 0, 0, 0, 0, 0, 27, 0, 0, 0, 0, 0, },
/* D K */ {31, 0, 0, 0, 0, 0, 0, 0, 6, 28, 0, 23, 0, 5, 54, 1, 0, 25, 1, 0, 14, 6, 0, 0, 1, 0, },
/* D L */ {60, 0, 0, 0, 246, 0, 0, 1, 360, 0, 0, 0, 0, 0, 38, 0, 0, 0, 0, 0, 5, 0, 0, 0, 18, 0, },
/* D M */ {58, 0, 0, 0, 27, 0, 0, 0, 89, 0, 1, 0, 0, 0, 22, 0, 0, 0, 0, 0, 7, 0, 0, 0, 4, 0, },
/* D N */ {23, 1, 1, 0, 49, 0, 1, 0, 429, 0, 0, 1, 0, 0, 6, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, },
/* D O */ {3, 103, 0, 5, 471, 11, 15, 0, 3, 0, 175, 63, 413, 65, 3, 56, 0, 53, 38, 23, 2, 29, 6, 0, 0, 0, },
/* D P */ {15, 0, 0, 0, 7, 0, 0, 0, 1, 0, 0, 15, 0, 0, 14, 0, 0, 28, 0, 0, 11, 0, 0, 0, 1, 0, },
/* D Q */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* D R */ {418, 0, 0, 0, 657, 0, 0, 0, 581, 0, 0, 0, 0, 0, 199, 0, 0, 0, 1, 0, 58, 1, 0, 0, 27, 0, },
/* D S */ {146, 150, 0, 73, 167, 179, 47, 57, 52, 154, 374, 151, 144, 34, 108, 176, 0, 90, 232, 277, 50, 91, 0, 0, 18, 0, },
/* D T */ {80, 5, 0, 0, 62, 4, 17, 2, 15, 4, 3, 15, 0, 1, 18, 3, 0, 33, 14, 1, 11, 9, 0, 0, 12, 0, },
/* D U */ {17, 9, 2, 0, 23, 7, 25, 0, 6, 0, 377, 38, 38, 49, 1, 10, 0, 16, 286, 12, 2, 2, 0, 0, 0, 1, },
/* D V */ {53, 0, 0, 0, 123, 0, 0, 0, 54, 0, 0, 0, 0, 0, 36, 0, 0, 0, 1, 0, 3, 0, 0, 0, 0, 0, },
/* D W */ {5, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* D X */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* D Y */ {0, 12, 0, 5, 1, 4, 2, 0, 0, 0, 63, 10, 2, 47, 0, 51, 0, 264, 15, 3, 0, 4, 0, 0, 0, 0, },
/* D Z */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, }},
/* E A */ {{63, 25, 2, 21, 15, 3, 11, 0, 0, 0, 77, 146, 31, 97, 0, 28, 0, 128, 28, 122, 18, 98, 0, 0, 0, 0, },
/* E B */ {292, 23, 0, 0, 362, 1, 0, 2, 108, 11, 0, 102, 0, 14, 247, 0, 0, 205, 1, 0, 100, 0, 0, 0, 110, 0, },
/* E C */ {2, 0, 4, 2, 20, 0, 1, 10, 1, 0, 5, 2, 1, 1, 8, 0, 1, 3, 1, 6, 4, 0, 0, 0, 0, 0, },
/* E D */ {332, 76, 2, 270, 930, 58, 32, 29, 393, 18, 43, 151, 23, 172, 138, 17, 0, 339, 502, 114, 53, 48, 3, 0, 71, 0, },
/* E E */ {1, 0, 3, 15, 0, 8, 16, 0, 14, 0, 31, 37, 7, 75, 0, 10, 0, 46, 11, 30, 0, 24, 0, 0, 0, 0, },
/* E F */ {256, 0, 0, 1, 175, 134, 1, 1, 173, 57, 4, 134, 2, 3, 622, 1, 0, 126, 27, 169, 87, 0, 0, 0, 25, 0, },
/* E G */ {228, 6, 0, 34, 552, 11, 723, 8, 204, 98, 11, 140, 16, 509, 69, 6, 0, 376, 95, 22, 88, 7, 0, 0, 33, 0, },
/* E H */ {391, 0, 0, 0, 121, 0, 0, 1, 26, 62, 0, 1, 1, 0, 242, 0, 0, 0, 0, 0, 154, 10, 0, 0, 19, 0, },
/* E I */ {13, 12, 4, 995, 388, 19, 47, 2, 13, 0, 176, 312, 171, 657, 3, 38, 0, 122, 404, 113, 2, 43, 0, 0, 0, 0, },
/* E J */ {26, 0, 0, 0, 25, 0, 0, 0, 1, 0, 0, 0, 0, 0, 16, 0, 0, 0, 0, 0, 19, 0, 0, 0, 0, 0, },
/* E K */ {332, 4, 0, 6, 288, 7, 4, 5, 54, 117, 698, 250, 7, 413, 566, 2, 0, 262, 1305, 1273, 154, 140, 0, 0, 40, 0, },
/* E L */ {476, 88, 2, 432, 999, 150, 304, 61, 1042, 28, 167, 1481, 72, 24, 305, 196, 0, 42, 2224, 655, 60, 407, 0, 0, 81, 0, },
/* E M */ {596, 113, 0, 31, 446, 40, 13, 11, 330, 10, 43, 48, 558, 190, 239, 279, 0, 21, 178, 156, 94, 16, 0, 0, 22, 0, },
/* E N */ {176, 85, 11, 1574, 855, 81, 932, 199, 403, 7, 330, 84, 34, 1291, 141, 36, 1, 72, 1556, 2082, 49, 82, 1, 0, 37, 13, },
/* E O */ {2, 9, 0, 8, 46, 17, 15, 0, 4, 0, 9, 41, 105, 20, 1, 119, 1, 172, 21, 7, 1, 34, 0, 0, 0, 1, },
/* E P */ {212, 0, 0, 0, 295, 0, 0, 2, 115, 3, 0, 261, 5, 23, 132, 115, 0, 286, 168, 76, 76, 1, 0, 0, 3, 0, },
/* E Q */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* E R */ {789, 319, 13, 766, 3415, 464, 587, 320, 2708, 83, 975, 414, 524, 874, 397, 229, 0, 518, 1711, 1086, 168, 736, 6, 1, 30, 1, },
/* E S */ {256, 60, 21, 32, 732, 65, 29, 44, 503, 195, 812, 204, 81, 170, 251, 303, 1, 50, 840, 2367, 162, 101, 0, 0, 105, 1, },
/* E T */ {624, 18, 3, 5, 809, 8, 16, 18, 430, 68, 10, 21, 9, 355, 285, 7, 0, 354, 858, 2193, 82, 8, 0, 0, 64, 1, },
/* E U */ {2, 1, 2, 13, 0, 7, 4, 2, 0, 0, 17, 12, 104, 58, 1, 1, 0, 54, 11, 155, 0, 0, 1, 1, 0, 0, },
/* E V */ {339, 36, 0, 38, 1076, 8, 3, 13, 383, 7, 20, 47, 9, 230, 103, 6, 0, 54, 39, 18, 7, 6, 0, 0, 11, 0, },
/* E W */ {3, 0, 1, 0, 0, 2, 0, 0, 1, 0, 0, 1, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 1, 2, },
/* E X */ {6, 1, 0, 0, 1, 1, 0, 1, 6, 0, 1, 0, 0, 0, 4, 2, 0, 1, 3, 1, 1, 0, 0, 1, 1, 0, },
/* E Y */ {35, 24, 1, 85, 233, 26, 16, 16, 14, 0, 71, 37, 10, 47, 5, 30, 0, 72, 127, 169, 0, 33, 1, 0, 0, 0, },
/* E Z */ {0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, 0, 0, 0, 4, }},
/* F A */ {{26, 121, 11, 15, 37, 1, 233, 1, 8, 1, 97, 281, 113, 237, 1, 3, 0, 495, 217, 151, 13, 26, 0, 3, 0, 0, },
/* F B */ {4, 0, 0, 0, 3, 0, 0, 0, 3, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, },
/* F C */ {0, 0, 1, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, },
/* F D */ {3, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* F E */ {8, 33, 3, 19, 10, 5, 8, 3, 165, 0, 139, 408, 91, 108, 2, 5, 0, 600, 190, 70, 1, 4, 0, 0, 0, 1, },
/* F F */ {16, 5, 0, 1, 371, 0, 1, 0, 73, 1, 6, 9, 14, 1, 18, 12, 0, 9, 25, 4, 16, 1, 0, 0, 0, 0, },
/* F G */ {1, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 1, 0, 0, 0, 0, 0, },
/* F H */ {0, 0, 0, 0, 1, 0, 0, 0, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* F I */ {11, 32, 8, 15, 38, 6, 49, 0, 0, 2, 255, 341, 3, 357, 15, 7, 0, 118, 544, 21, 1, 5, 0, 0, 0, 0, },
/* F J */ {42, 0, 0, 0, 276, 0, 0, 0, 0, 0, 0, 0, 0, 0, 227, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* F K */ {1, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 1, 0, 0, 7, 0, 0, 1, 0, 0, 1, 0, 0, 0, 0, 0, },
/* F L */ {317, 0, 0, 0, 171, 0, 1, 0, 86, 0, 0, 0, 0, 1, 211, 0, 0, 0, 0, 0, 99, 0, 0, 0, 306, 0, },
/* F M */ {10, 0, 0, 0, 4, 0, 0, 0, 4, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, },
/* F N */ {4, 1, 0, 0, 9, 0, 0, 0, 5, 0, 0, 1, 0, 0, 2, 0, 0, 0, 1, 0, 4, 0, 0, 0, 1, 0, },
/* F O */ {2, 10, 0, 1, 716, 0, 9, 0, 3, 0, 12, 403, 10, 233, 0, 2, 0, 3736, 76, 201, 6, 0, 0, 1, 0, 0, },
/* F P */ {3, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 6, 1, 0, 1, 0, 0, 0, 0, 0, },
/* F Q */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* F R */ {421, 2, 0, 0, 409, 2, 0, 0, 414, 1, 2, 1, 1, 0, 196, 1, 0, 0, 3, 0, 85, 1, 0, 0, 54, 0, },
/* F S */ {3, 0, 0, 0, 42, 0, 0, 2, 8, 2, 10, 5, 0, 3, 3, 1, 0, 0, 3, 10, 0, 0, 1, 0, 0, 0, },
/* F T */ {31, 21, 1, 3, 290, 35, 5, 5, 47, 0, 24, 14, 10, 15, 16, 19, 0, 7, 386, 26, 10, 24, 1, 0, 2, 0, },
/* F U */ {0, 1, 0, 0, 0, 0, 123, 1, 0, 1, 21, 211, 2, 361, 0, 0, 0, 45, 52, 15, 0, 0, 0, 0, 0, 0, },
/* F V */ {1, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* F W */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* F X */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* F Y */ {0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 1, 199, 6, 4, 1, 0, 0, 56, 55, 6, 0, 0, 0, 0, 0, 0, },
/* F Z */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, }},
/* G A */ {{205, 15, 0, 12, 7, 10, 12, 2, 0, 0, 7, 127, 97, 609, 3, 19, 0, 264, 251, 110, 34, 176, 1, 0, 0, 2, },
/* G B */ {16, 0, 0, 0, 29, 0, 0, 0, 10, 5, 0, 14, 0, 0, 31, 0, 0, 30, 0, 0, 10, 0, 0, 0, 16, 0, },
/* G C */ {1, 0, 0, 0, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, },
/* G D */ {47, 0, 0, 0, 246, 1, 1, 0, 13, 0, 1, 2, 0, 0, 75, 2, 0, 18, 2, 0, 0, 0, 0, 0, 7, 0, },
/* G E */ {39, 123, 0, 50, 6, 61, 20, 32, 52, 4, 77, 583, 88, 849, 77, 40, 0, 864, 213, 282, 10, 72, 0, 0, 1, 0, },
/* G F */ {19, 0, 0, 0, 13, 0, 0, 0, 17, 12, 0, 12, 0, 0, 76, 0, 0, 11, 0, 0, 13, 0, 0, 0, 4, 0, },
/* G G */ {20, 8, 1, 5, 515, 11, 0, 11, 165, 67, 6, 17, 8, 0, 9, 10, 0, 37, 149, 20, 8, 11, 0, 0, 2, 0, },
/* G H */ {28, 0, 0, 0, 487, 0, 0, 0, 4, 6, 0, 0, 0, 0, 19, 0, 0, 0, 0, 13, 14, 0, 0, 0, 3, 1, },
/* G I */ {17, 20, 1, 16, 32, 251, 52, 0, 1, 0, 62, 21, 36, 315, 56, 15, 0, 34, 217, 156, 9, 153, 0, 0, 0, 0, },
/* G J */ {31, 0, 0, 0, 534, 0, 0, 0, 0, 0, 0, 0, 0, 0, 261, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, },
/* G K */ {57, 0, 0, 0, 0, 0, 0, 0, 5, 8, 0, 9, 0, 6, 31, 0, 0, 14, 1, 0, 11, 4, 0, 0, 1, 0, },
/* G L */ {219, 5, 0, 2, 315, 2, 1, 0, 125, 1, 0, 2, 1, 0, 102, 1, 0, 1, 7, 0, 12, 3, 0, 0, 17, 0, },
/* G M */ {67, 1, 1, 0, 40, 0, 0, 0, 11, 2, 0, 1, 0, 0, 21, 0, 0, 0, 0, 1, 9, 0, 0, 0, 1, 0, },
/* G N */ {146, 13, 0, 10, 264, 16, 2, 8, 399, 1, 14, 7, 2, 1, 54, 8, 0, 4, 74, 7, 9, 9, 0, 0, 2, 0, },
/* G O */ {1, 2, 0, 166, 49, 4, 45, 0, 4, 0, 7, 67, 20, 68, 2, 10, 0, 68, 13, 28, 5, 2, 1, 0, 0, 0, },
/* G P */ {11, 0, 0, 1, 18, 0, 0, 0, 5, 0, 0, 20, 1, 0, 6, 0, 0, 37, 0, 0, 6, 0, 0, 0, 0, 0, },
/* G Q */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* G R */ {1013, 0, 0, 0, 616, 0, 0, 0, 177, 1, 0, 1, 0, 0, 222, 0, 0, 0, 0, 0, 584, 0, 0, 0, 53, 0, },
/* G S */ {268, 225, 3, 131, 201, 352, 90, 78, 103, 29, 406, 228, 322, 63, 209, 423, 0, 220, 445, 582, 87, 202, 0, 0, 17, 0, },
/* G T */ {20, 0, 0, 0, 37, 1, 0, 0, 48, 1, 0, 1, 0, 0, 16, 0, 0, 33, 3, 0, 16, 10, 0, 0, 6, 0, },
/* G U */ {16, 7, 1, 76, 2, 6, 3, 0, 9, 0, 0, 257, 46, 25, 0, 0, 0, 75, 22, 91, 0, 7, 0, 0, 1, 0, },
/* G V */ {42, 0, 0, 0, 42, 0, 0, 0, 46, 0, 0, 0, 0, 0, 12, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, },
/* G W */ {3, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* G X */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* G Y */ {0, 0, 0, 1, 1, 0, 2, 0, 0, 0, 0, 30, 30, 28, 0, 6, 0, 9, 6, 20, 0, 3, 0, 0, 0, 0, },
/* G Z */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, }},
/* H A */ {{362, 27, 1, 11, 47, 8, 116, 1, 26, 0, 36, 325, 119, 631, 0, 8, 0, 178, 96, 46, 97, 245, 4, 0, 1, 0, },
/* H B */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* H C */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, },
/* H D */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* H E */ {11, 10, 1, 37, 1, 34, 21, 1, 222, 0, 47, 372, 62, 318, 5, 12, 0, 225, 106, 1122, 1, 42, 1, 0, 1, 0, },
/* H F */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* H G */ {0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* H H */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, },
/* H I */ {9, 6, 5, 2, 10, 20, 6, 1, 0, 0, 4, 55, 42, 71, 3, 21, 0, 12, 129, 19, 1, 3, 0, 0, 0, 3, },
/* H J */ {7, 0, 0, 0, 435, 0, 0, 0, 0, 0, 0, 0, 0, 0, 45, 0, 0, 0, 0, 0, 58, 0, 0, 0, 0, 0, },
/* H K */ {0, 0, 0, 0, 0, 1, 0, 1, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* H L */ {3, 0, 1, 0, 2, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, },
/* H M */ {3, 0, 0, 0, 6, 0, 0, 0, 3, 0, 1, 0, 0, 0, 1, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, },
/* H N */ {3, 0, 0, 0, 1, 0, 0, 0, 1, 0, 0, 0, 0, 1, 1, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, },
/* H O */ {0, 17, 7, 84, 679, 23, 46, 1, 2, 0, 7, 616, 57, 38, 3, 62, 0, 101, 25, 55, 3, 237, 14, 0, 0, 0, },
/* H P */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* H Q */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* H R */ {2, 0, 0, 0, 3, 0, 1, 0, 10, 0, 0, 0, 0, 0, 2, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, },
/* H S */ {0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, },
/* H T */ {0, 0, 0, 0, 5, 0, 0, 0, 2, 0, 0, 0, 0, 0, 2, 0, 0, 0, 5, 1, 0, 0, 0, 0, 0, 0, },
/* H U */ {3, 2, 1, 46, 4, 3, 66, 0, 2, 0, 10, 79, 47, 144, 0, 2, 0, 43, 403, 7, 0, 1, 0, 0, 0, 0, },
/* H V */ {37, 0, 0, 0, 48, 0, 0, 0, 93, 0, 0, 0, 0, 0, 16, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* H W */ {1, 0, 0, 0, 1, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, },
/* H X */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* H Y */ {1, 7, 0, 42, 3, 1, 24, 0, 0, 0, 6, 45, 2, 2, 0, 40, 0, 18, 9, 52, 0, 1, 0, 0, 0, 0, },
/* H Z */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, }},
/* I A */ {{31, 31, 1, 15, 12, 7, 46, 3, 1, 0, 51, 493, 22, 146, 2, 5, 0, 53, 62, 83, 0, 21, 1, 0, 0, 1, },
/* I B */ {34, 18, 1, 0, 127, 0, 0, 0, 49, 0, 0, 72, 2, 1, 10, 0, 0, 33, 2, 2, 62, 0, 1, 0, 15, 0, },
/* I C */ {25, 1, 3, 1, 82, 1, 0, 12, 17, 1, 16, 0, 0, 1, 5, 0, 0, 3, 3, 6, 4, 0, 1, 0, 1, 0, },
/* I D */ {97, 8, 0, 249, 834, 10, 16, 7, 126, 8, 11, 59, 6, 23, 30, 6, 0, 146, 784, 49, 22, 11, 0, 0, 8, 0, },
/* I E */ {25, 41, 6, 13, 3, 52, 17, 12, 6, 2, 36, 137, 22, 297, 23, 26, 0, 493, 83, 127, 7, 20, 0, 0, 0, 0, },
/* I F */ {39, 0, 3, 0, 35, 127, 0, 0, 148, 4, 0, 18, 0, 0, 86, 0, 0, 21, 2, 874, 17, 0, 0, 0, 0, 0, },
/* I G */ {109, 19, 1, 20, 284, 18, 169, 495, 60, 27, 13, 22, 36, 236, 22, 19, 0, 75, 166, 16, 55, 30, 3, 0, 2, 0, },
/* I H */ {16, 0, 0, 0, 42, 0, 0, 0, 6, 4, 0, 1, 0, 0, 20, 0, 0, 0, 0, 1, 9, 2, 0, 0, 0, 0, },
/* I I */ {0, 0, 0, 9, 0, 0, 1, 0, 0, 0, 0, 0, 2, 30, 0, 0, 0, 0, 2, 2, 0, 0, 0, 0, 0, 0, },
/* I J */ {3, 0, 0, 0, 9, 1, 0, 0, 2, 0, 0, 0, 0, 0, 8, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* I K */ {403, 10, 0, 5, 517, 9, 4, 30, 34, 12, 1435, 224, 4, 76, 146, 1, 0, 198, 200, 417, 61, 38, 0, 0, 3, 0, },
/* I L */ {108, 205, 2, 368, 281, 96, 61, 36, 420, 244, 152, 1217, 146, 24, 103, 66, 0, 38, 325, 290, 37, 47, 0, 0, 2, 0, },
/* I M */ {139, 15, 2, 2, 343, 12, 0, 3, 103, 1, 4, 23, 97, 4, 56, 118, 0, 14, 56, 14, 152, 3, 1, 0, 2, 0, },
/* I N */ {432, 62, 14, 707, 468, 222, 9490, 32, 412, 219, 222, 43, 33, 1511, 87, 34, 0, 23, 620, 493, 71, 111, 0, 0, 6, 1, },
/* I O */ {9, 3, 3, 96, 96, 15, 23, 1, 4, 1, 21, 73, 39, 153, 3, 17, 0, 54, 38, 106, 5, 8, 1, 0, 0, 0, },
/* I P */ {31, 3, 0, 0, 163, 1, 1, 2, 15, 0, 1, 82, 1, 14, 20, 208, 0, 28, 191, 28, 14, 0, 0, 0, 3, 1, },
/* I Q */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* I R */ {90, 14, 1, 13, 260, 14, 9, 5, 77, 1, 373, 12, 61, 1, 48, 8, 2, 33, 34, 12, 39, 32, 1, 0, 0, 0, },
/* I S */ {206, 64, 11, 26, 1113, 48, 14, 45, 269, 396, 1801, 91, 308, 174, 158, 121, 0, 19, 298, 1626, 25, 30, 0, 0, 26, 1, },
/* I T */ {290, 8, 1, 3, 849, 9, 6, 9, 425, 3, 5, 18, 28, 37, 83, 3, 0, 75, 78, 792, 233, 8, 0, 0, 6, 8, },
/* I U */ {1, 3, 1, 0, 0, 0, 0, 0, 0, 0, 0, 2, 336, 5, 0, 3, 0, 5, 29, 15, 0, 0, 0, 0, 0, 0, },
/* I V */ {263, 19, 0, 12, 540, 13, 7, 11, 340, 1, 19, 14, 10, 53, 25, 7, 0, 21, 151, 14, 10, 9, 0, 0, 1, 0, },
/* I W */ {2, 0, 0, 0, 0, 1, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, },
/* I X */ {0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, },
/* I Y */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* I Z */ {2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, }},
/* J A */ {{59, 8, 9, 3, 218, 6, 21, 6, 1, 1, 153, 38, 58, 58, 2, 13, 0, 48, 22, 8, 6, 12, 0, 1, 0, 19, },
/* J B */ {1, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, },
/* J C */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* J D */ {0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, },
/* J E */ {14, 51, 0, 101, 12, 281, 69, 12, 16, 0, 346, 630, 359, 746, 14, 33, 0, 830, 144, 234, 5, 76, 0, 0, 0, 0, },
/* J F */ {1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 4, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, },
/* J G */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* J H */ {2, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* J I */ {2, 3, 0, 2, 0, 0, 2, 1, 2, 0, 16, 0, 3, 5, 0, 0, 0, 3, 10, 2, 1, 0, 0, 0, 0, 0, },
/* J J */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* J K */ {1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, },
/* J L */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* J M */ {0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, },
/* J N */ {0, 0, 0, 0, 1, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, },
/* J O */ {6, 41, 3, 8, 1429, 2, 10, 13, 1, 1, 54, 42, 23, 3162, 0, 1, 0, 436, 18, 20, 44, 3, 0, 0, 0, 0, },
/* J P */ {2, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, },
/* J Q */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* J R */ {0, 0, 0, 0, 2, 0, 0, 0, 2, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* J S */ {0, 0, 0, 0, 1, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, },
/* J T */ {0, 0, 0, 0, 2, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, },
/* J U */ {10, 50, 0, 17, 16, 0, 12, 0, 2, 0, 159, 211, 7, 49, 3, 19, 0, 45, 57, 15, 1, 24, 0, 0, 0, 0, },
/* J V */ {1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* J W */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* J X */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* J Y */ {0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 1, 0, 5, 1, 0, 0, 0, 0, 0, 0, 0, },
/* J Z */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, }},
/* K A */ {{185, 88, 1, 201, 4, 87, 7, 6, 28, 5, 88, 506, 279, 506, 4, 887, 0, 463, 439, 446, 35, 56, 0, 0, 0, 0, },
/* K B */ {25, 0, 0, 0, 30, 0, 0, 1, 12, 2, 0, 5, 1, 0, 19, 0, 0, 21, 0, 0, 7, 0, 0, 0, 7, 0, },
/* K C */ {2, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* K D */ {13, 0, 0, 0, 9, 0, 0, 0, 8, 0, 0, 0, 0, 0, 94, 0, 0, 9, 0, 0, 1, 0, 0, 0, 6, 0, },
/* K E */ {43, 154, 2, 170, 26, 150, 50, 178, 54, 10, 147, 753, 105, 335, 55, 145, 0, 1329, 479, 502, 13, 108, 0, 0, 12, 0, },
/* K F */ {19, 0, 0, 0, 12, 0, 0, 0, 25, 0, 0, 10, 0, 0, 53, 0, 0, 11, 0, 0, 18, 0, 0, 0, 2, 0, },
/* K G */ {8, 1, 0, 0, 2, 0, 0, 0, 4, 4, 0, 5, 1, 0, 7, 0, 0, 46, 0, 0, 3, 0, 0, 0, 1, 0, },
/* K H */ {36, 0, 0, 0, 29, 0, 0, 0, 7, 5, 0, 0, 1, 0, 30, 0, 0, 0, 1, 1, 12, 4, 0, 0, 2, 1, },
/* K I */ {22, 8, 1, 9, 14, 117, 6, 5, 3, 3, 52, 201, 27, 725, 7, 264, 0, 124, 93, 77, 3, 114, 2, 0, 0, 0, },
/* K J */ {159, 0, 0, 0, 881, 0, 0, 0, 0, 0, 0, 0, 0, 0, 551, 0, 0, 0, 0, 0, 12, 0, 0, 0, 0, 0, },
/* K K */ {106, 60, 1, 23, 1550, 62, 21, 26, 94, 25, 1, 52, 39, 11, 125, 43, 0, 32, 199, 43, 46, 44, 1, 0, 7, 0, },
/* K L */ {532, 0, 0, 0, 310, 0, 0, 0, 377, 0, 0, 0, 1, 0, 221, 0, 0, 0, 1, 0, 132, 0, 0, 0, 30, 0, },
/* K M */ {45, 0, 0, 0, 25, 0, 0, 0, 6, 0, 0, 0, 0, 0, 14, 0, 0, 0, 0, 0, 5, 0, 0, 0, 5, 0, },
/* K N */ {121, 0, 0, 1, 187, 0, 0, 0, 657, 0, 0, 0, 1, 0, 102, 0, 0, 1, 1, 0, 53, 0, 0, 0, 26, 0, },
/* K O */ {22, 53, 2, 75, 128, 32, 216, 65, 7, 1, 90, 810, 866, 1511, 36, 194, 0, 538, 246, 134, 5, 38, 2, 0, 0, 0, },
/* K P */ {14, 0, 0, 1, 6, 0, 0, 0, 4, 0, 0, 9, 1, 0, 11, 0, 0, 41, 3, 0, 4, 0, 0, 0, 0, 0, },
/* K Q */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* K R */ {607, 0, 0, 0, 567, 1, 0, 0, 1023, 0, 0, 0, 0, 0, 318, 0, 0, 0, 0, 0, 111, 0, 0, 0, 117, 0, },
/* K S */ {202, 63, 0, 41, 421, 60, 18, 17, 207, 856, 116, 84, 55, 24, 188, 340, 0, 34, 45, 609, 48, 34, 1, 0, 22, 0, },
/* K T */ {119, 51, 0, 16, 464, 59, 22, 27, 480, 4, 33, 41, 31, 41, 481, 25, 0, 170, 283, 36, 164, 19, 0, 0, 13, 0, },
/* K U */ {1, 25, 0, 113, 48, 20, 1, 2, 2, 2, 2, 451, 223, 309, 2, 45, 0, 384, 68, 82, 3, 6, 3, 0, 0, 0, },
/* K V */ {275, 0, 0, 0, 261, 0, 0, 0, 344, 0, 0, 0, 0, 0, 40, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, },
/* K W */ {0, 0, 0, 0, 2, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, },
/* K X */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* K Y */ {1, 9, 0, 6, 8, 6, 25, 1, 1, 0, 3, 104, 12, 32, 1, 5, 0, 19, 101, 122, 0, 14, 0, 0, 0, 0, },
/* K Z */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, }},
/* L A */ {{454, 85, 8, 240, 448, 29, 851, 12, 15, 0, 169, 27, 184, 1479, 5, 94, 0, 301, 835, 546, 179, 151, 2, 0, 10, 1, },
/* L B */ {154, 0, 0, 0, 115, 0, 0, 0, 21, 5, 0, 24, 1, 0, 50, 0, 0, 66, 0, 0, 119, 0, 0, 0, 26, 0, },
/* L C */ {2, 0, 0, 0, 3, 0, 0, 3, 0, 0, 1, 0, 0, 0, 4, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, },
/* L D */ {69, 14, 0, 3, 618, 23, 10, 3, 207, 3, 4, 7, 3, 67, 43, 1, 0, 117, 200, 42, 11, 6, 0, 0, 15, 0, },
/* L E */ {46, 158, 1, 661, 26, 216, 839, 58, 426, 8, 537, 168, 488, 631, 51, 151, 0, 1060, 540, 587, 86, 313, 1, 6, 6, 0, },
/* L F */ {105, 3, 1, 1, 95, 0, 1, 1, 41, 13, 1, 30, 0, 0, 166, 0, 0, 35, 3, 2, 16, 0, 0, 0, 6, 0, },
/* L G */ {65, 8, 0, 5, 247, 8, 1, 4, 49, 30, 13, 16, 6, 16, 39, 3, 0, 50, 120, 23, 15, 0, 0, 0, 0, 0, },
/* L H */ {59, 0, 0, 0, 48, 0, 0, 0, 8, 7, 0, 0, 0, 0, 35, 0, 0, 0, 0, 0, 14, 5, 0, 0, 9, 0, },
/* L I */ {66, 49, 10, 112, 190, 32, 1260, 2, 0, 1, 535, 38, 102, 2232, 87, 108, 0, 25, 692, 738, 16, 268, 0, 0, 0, 2, },
/* L J */ {36, 3, 0, 1, 295, 3, 0, 2, 3, 0, 2, 1, 0, 1, 193, 4, 0, 4, 3, 1, 9, 1, 0, 0, 0, 0, },
/* L K */ {135, 1, 1, 0, 399, 0, 1, 4, 17, 38, 1, 40, 3, 62, 192, 2, 0, 33, 14, 4, 36, 12, 0, 0, 16, 0, },
/* L L */ {276, 81, 0, 43, 1512, 80, 50, 31, 660, 4, 89, 0, 128, 8, 187, 40, 0, 47, 270, 71, 79, 62, 0, 0, 23, 0, },
/* L M */ {123, 7, 0, 2, 180, 8, 2, 3, 27, 0, 10, 4, 3, 1, 50, 9, 0, 5, 19, 4, 25, 3, 0, 0, 5, 0, },
/* L N */ {24, 1, 0, 0, 37, 0, 1, 0, 16, 0, 0, 0, 0, 0, 11, 0, 0, 1, 0, 0, 9, 0, 0, 0, 1, 0, },
/* L O */ {27, 21, 5, 192, 1267, 35, 472, 10, 22, 5, 347, 13, 307, 159, 3, 61, 0, 112, 137, 102, 5, 292, 7, 0, 1, 0, },
/* L P */ {75, 0, 0, 0, 157, 0, 1, 3, 16, 0, 0, 36, 0, 1, 41, 0, 0, 73, 6, 4, 11, 0, 0, 0, 0, 0, },
/* L Q */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, },
/* L R */ {45, 0, 1, 0, 88, 0, 0, 0, 19, 0, 0, 0, 0, 0, 43, 0, 0, 0, 0, 0, 15, 0, 0, 0, 7, 0, },
/* L S */ {84, 48, 1, 42, 1663, 45, 8, 25, 81, 26, 475, 49, 61, 32, 81, 78, 0, 18, 63, 310, 23, 59, 0, 0, 80, 0, },
/* L T */ {288, 27, 0, 14, 342, 24, 5, 15, 172, 16, 23, 14, 23, 50, 48, 25, 0, 113, 59, 18, 206, 30, 0, 0, 15, 1, },
/* L U */ {2, 75, 2, 23, 70, 143, 40, 1, 21, 1, 175, 8, 154, 123, 12, 39, 0, 53, 121, 235, 0, 2, 0, 10, 0, 0, },
/* L V */ {112, 42, 0, 18, 243, 36, 19, 12, 84, 3, 32, 20, 30, 5, 58, 17, 0, 14, 59, 24, 8, 14, 0, 0, 0, 0, },
/* L W */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* L X */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* L Y */ {8, 10, 3, 105, 8, 14, 53, 10, 2, 0, 122, 3, 29, 103, 4, 29, 0, 17, 418, 140, 2, 19, 1, 0, 0, 0, },
/* L Z */ {1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, }},
/* M A */ {{742, 8, 4, 38, 30, 11, 115, 7, 21, 14, 273, 282, 10, 955, 2, 12, 0, 495, 590, 662, 35, 20, 0, 2, 1, 6, },
/* M B */ {109, 0, 0, 1, 136, 0, 0, 1, 55, 4, 0, 23, 0, 0, 67, 0, 0, 56, 1, 0, 65, 0, 0, 0, 21, 0, },
/* M C */ {0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* M D */ {16, 0, 0, 0, 12, 0, 0, 0, 16, 0, 0, 0, 0, 0, 14, 0, 0, 23, 0, 0, 1, 0, 0, 0, 4, 0, },
/* M E */ {47, 53, 2, 361, 8, 39, 51, 25, 53, 0, 146, 622, 32, 1223, 11, 20, 0, 906, 252, 584, 9, 23, 0, 4, 5, 3, },
/* M F */ {36, 2, 0, 1, 43, 0, 0, 0, 23, 3, 1, 21, 0, 0, 80, 0, 0, 30, 0, 0, 166, 0, 0, 0, 13, 0, },
/* M G */ {63, 0, 0, 0, 3, 0, 0, 0, 12, 7, 0, 1, 0, 0, 3, 0, 0, 11, 0, 0, 4, 0, 0, 0, 0, 0, },
/* M H */ {10, 0, 0, 0, 141, 0, 0, 0, 3, 6, 0, 0, 0, 0, 16, 0, 0, 0, 0, 1, 10, 4, 0, 0, 0, 1, },
/* M I */ {12, 7, 6, 296, 52, 9, 28, 1, 2, 5, 108, 415, 13, 748, 2, 5, 0, 17, 361, 176, 6, 4, 0, 1, 0, 0, },
/* M J */ {3, 0, 0, 0, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 44, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, },
/* M K */ {41, 0, 0, 0, 0, 0, 1, 0, 5, 16, 0, 13, 0, 1, 57, 0, 0, 31, 1, 0, 8, 6, 0, 0, 0, 0, },
/* M L */ {32, 0, 0, 0, 160, 0, 1, 0, 137, 0, 0, 1, 0, 0, 29, 0, 0, 0, 0, 0, 8, 0, 0, 0, 3, 0, },
/* M M */ {136, 0, 0, 0, 1472, 0, 0, 0, 121, 0, 0, 0, 0, 0, 30, 1, 0, 0, 0, 0, 196, 0, 0, 0, 3, 0, },
/* M N */ {39, 0, 0, 32, 79, 0, 1, 0, 124, 0, 0, 0, 0, 1, 5, 0, 0, 0, 3, 2, 3, 1, 0, 0, 0, 0, },
/* M O */ {5, 26, 1, 261, 444, 7, 29, 2, 4, 1, 31, 72, 31, 224, 0, 26, 0, 311, 68, 295, 4, 10, 0, 0, 0, 1, },
/* M P */ {96, 2, 0, 5, 474, 4, 3, 7, 51, 0, 7, 103, 3, 4, 134, 2, 0, 88, 24, 16, 32, 5, 0, 0, 2, 0, },
/* M Q */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, },
/* M R */ {226, 0, 0, 1, 67, 0, 0, 0, 21, 0, 1, 0, 0, 0, 21, 0, 0, 0, 0, 0, 5, 0, 0, 0, 4, 0, },
/* M S */ {35, 32, 1, 17, 119, 54, 21, 12, 28, 6, 104, 50, 28, 37, 73, 61, 0, 16, 49, 334, 22, 26, 0, 0, 21, 0, },
/* M T */ {39, 1, 0, 0, 61, 0, 0, 2, 78, 1, 0, 2, 3, 0, 5, 0, 0, 43, 2, 0, 7, 12, 0, 0, 5, 0, },
/* M U */ {0, 1, 0, 11, 17, 10, 33, 6, 0, 0, 7, 310, 35, 255, 0, 0, 0, 49, 234, 61, 0, 0, 0, 0, 0, 0, },
/* M V */ {43, 0, 0, 0, 47, 0, 0, 0, 44, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, },
/* M W */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, },
/* M X */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* M Y */ {4, 0, 4, 1, 1, 0, 16, 2, 0, 0, 46, 5, 0, 75, 0, 0, 0, 34, 14, 12, 0, 0, 0, 0, 0, 0, },
/* M Z */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, }
 }};

  static void fill(GpwData xx) {
    int c1,c2,c3;
      for (c1=0; c1 < 13; c1++) {
	for (c2=0; c2 < 26; c2++) {
	  for (c3=0; c3 < 26; c3++) {
	    xx.set(c1, c2, c3, tris1[c1][c2][c3]);
	  } // for c3
	} // for c2
      } // for c1
  } // fill()

} // GpwDataInit1

class GpwDataInit2 {

  final static short tris2[][][] = {{ /* [13][26][26] */
/* N A */ {108, 68, 13, 240, 247, 24, 37, 1, 11, 1, 74, 578, 61, 163, 1, 56, 0, 197, 201, 346, 38, 147, 0, 0, 0, 11, },
/* N B */ {81, 1, 1, 0, 66, 0, 0, 0, 31, 5, 0, 26, 0, 0, 43, 0, 0, 64, 0, 0, 53, 0, 0, 0, 35, 0, },
/* N C */ {3, 2, 0, 0, 17, 0, 0, 26, 7, 0, 0, 0, 0, 0, 4, 0, 0, 2, 1, 1, 0, 0, 0, 0, 4, 0, },
/* N D */ {362, 113, 0, 13, 2222, 46, 23, 42, 478, 5, 40, 396, 21, 18, 233, 26, 0, 320, 583, 136, 256, 63, 1, 0, 19, 0, },
/* N E */ {80, 135, 4, 251, 10, 119, 79, 94, 52, 8, 204, 347, 160, 256, 40, 111, 0, 1025, 826, 445, 32, 174, 9, 0, 5, 3, },
/* N F */ {93, 0, 1, 0, 86, 1, 0, 0, 67, 11, 0, 73, 0, 0, 243, 0, 0, 38, 0, 0, 17, 0, 0, 0, 3, 0, },
/* N G */ {187, 60, 0, 221, 1295, 60, 14, 27, 113, 34, 62, 119, 26, 59, 63, 28, 0, 189, 3732, 99, 30, 62, 0, 0, 6, 0, },
/* N H */ {58, 0, 1, 0, 219, 1, 0, 1, 13, 14, 1, 0, 0, 0, 90, 0, 0, 0, 0, 0, 20, 10, 0, 0, 6, 0, },
/* N I */ {58, 18, 11, 29, 49, 39, 37, 7, 0, 1, 290, 30, 42, 3379, 93, 49, 0, 10, 733, 242, 80, 205, 0, 3, 0, 1, },
/* N J */ {25, 0, 0, 0, 236, 0, 0, 0, 2, 0, 0, 0, 0, 0, 9, 0, 0, 0, 0, 0, 26, 0, 0, 0, 0, 0, },
/* N K */ {108, 8, 0, 4, 524, 18, 6, 2, 38, 55, 13, 71, 6, 31, 137, 6, 0, 75, 201, 238, 110, 25, 0, 0, 1, 0, },
/* N L */ {169, 0, 0, 0, 327, 1, 0, 1, 96, 1, 0, 0, 0, 0, 62, 0, 0, 0, 1, 0, 14, 1, 0, 0, 14, 0, },
/* N M */ {83, 0, 0, 0, 45, 0, 0, 0, 11, 0, 0, 0, 0, 0, 28, 0, 0, 0, 0, 0, 7, 0, 0, 0, 1, 0, },
/* N N */ {98, 98, 0, 68, 1242, 122, 71, 129, 466, 7, 109, 213, 46, 0, 207, 56, 0, 76, 979, 213, 22, 88, 0, 0, 13, 0, },
/* N O */ {1, 26, 3, 11, 397, 9, 32, 0, 6, 0, 35, 117, 316, 91, 0, 54, 0, 375, 69, 99, 2, 38, 2, 0, 0, 2, },
/* N P */ {34, 0, 0, 1, 17, 0, 0, 0, 11, 0, 1, 29, 0, 0, 13, 0, 0, 64, 1, 0, 6, 0, 0, 0, 1, 0, },
/* N Q */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, },
/* N R */ {35, 0, 0, 0, 71, 1, 0, 0, 55, 0, 2, 0, 0, 0, 30, 0, 0, 1, 0, 1, 7, 0, 1, 0, 21, 0, },
/* N S */ {286, 170, 5, 82, 1081, 221, 52, 74, 401, 221, 754, 212, 166, 91, 226, 367, 0, 114, 273, 1006, 192, 185, 0, 0, 103, 0, },
/* N T */ {491, 41, 2, 8, 1124, 54, 33, 20, 374, 11, 28, 64, 30, 41, 383, 22, 0, 606, 106, 25, 64, 19, 1, 0, 52, 3, },
/* N U */ {11, 7, 0, 16, 17, 11, 10, 1, 20, 0, 5, 29, 141, 19, 1, 8, 0, 28, 85, 58, 4, 2, 0, 0, 0, 0, },
/* N V */ {101, 0, 0, 0, 189, 0, 0, 1, 99, 0, 0, 0, 0, 0, 34, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, },
/* N W */ {1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* N X */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* N Y */ {14, 19, 2, 6, 11, 13, 5, 23, 11, 0, 16, 27, 23, 29, 10, 11, 0, 14, 31, 111, 6, 9, 0, 0, 0, 2, },
/* N Z */ {3, 0, 0, 0, 7, 0, 0, 0, 2, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 4, 0, }},
/* O A */ {{5, 0, 2, 2, 0, 0, 7, 0, 0, 1, 14, 32, 4, 16, 0, 3, 0, 101, 10, 9, 3, 6, 0, 0, 0, 0, },
/* O B */ {61, 174, 0, 4, 48, 0, 0, 0, 48, 20, 1, 210, 0, 0, 21, 0, 0, 10, 36, 0, 7, 0, 0, 0, 6, 0, },
/* O C */ {4, 0, 2, 0, 3, 0, 0, 2, 1, 0, 39, 0, 0, 0, 2, 0, 0, 1, 0, 0, 0, 0, 0, 0, 2, 0, },
/* O D */ {24, 6, 1, 76, 577, 12, 8, 6, 108, 2, 18, 15, 4, 12, 40, 10, 0, 16, 92, 52, 385, 12, 2, 0, 17, 0, },
/* O E */ {17, 73, 3, 511, 46, 178, 205, 19, 12, 3, 734, 668, 552, 831, 14, 416, 0, 2468, 738, 580, 11, 533, 0, 1, 1311, 0, },
/* O F */ {44, 0, 0, 0, 58, 234, 0, 0, 74, 3, 0, 8, 0, 1, 69, 0, 0, 15, 2, 44, 6, 0, 0, 0, 22, 0, },
/* O G */ {40, 21, 1, 18, 113, 22, 72, 6, 305, 2, 9, 16, 12, 134, 18, 3, 0, 423, 75, 11, 7, 9, 0, 0, 2, 0, },
/* O H */ {18, 0, 0, 0, 22, 0, 0, 0, 3, 6, 0, 0, 1, 4, 62, 0, 0, 0, 0, 0, 3, 0, 0, 0, 3, 0, },
/* O I */ {1, 0, 0, 30, 5, 1, 2, 0, 0, 0, 18, 7, 2, 26, 0, 0, 0, 3, 30, 4, 0, 0, 0, 0, 0, 0, },
/* O J */ {10, 0, 0, 0, 8, 0, 0, 0, 1, 0, 1, 0, 0, 0, 3, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, },
/* O K */ {190, 6, 0, 1, 81, 15, 0, 15, 14, 17, 380, 18, 12, 29, 115, 7, 0, 60, 297, 93, 139, 9, 0, 0, 1, 0, },
/* O L */ {130, 43, 3, 628, 655, 34, 18, 8, 537, 168, 399, 507, 55, 4, 484, 36, 0, 10, 73, 58, 98, 80, 0, 0, 58, 0, },
/* O M */ {227, 139, 0, 23, 181, 89, 64, 138, 261, 3, 61, 46, 650, 32, 118, 300, 1, 248, 557, 69, 19, 39, 0, 0, 3, 0, },
/* O N */ {322, 23, 7, 269, 444, 128, 334, 7, 308, 23, 111, 22, 10, 135, 210, 17, 0, 15, 1590, 818, 26, 67, 0, 1, 17, 1, },
/* O O */ {0, 0, 1, 4, 1, 3, 0, 0, 0, 0, 9, 12, 6, 0, 0, 12, 0, 38, 2, 8, 0, 2, 0, 0, 0, 0, },
/* O P */ {62, 1, 0, 0, 215, 0, 1, 4, 132, 0, 3, 54, 4, 2, 62, 1375, 0, 33, 34, 69, 22, 0, 0, 0, 3, 0, },
/* O Q */ {0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, },
/* O R */ {294, 425, 5, 1311, 562, 190, 485, 339, 550, 11, 196, 142, 1018, 217, 86, 126, 0, 213, 1171, 1091, 82, 156, 4, 0, 9, 1, },
/* O S */ {45, 11, 6, 2, 396, 29, 2, 6, 257, 253, 72, 19, 23, 16, 45, 38, 0, 0, 161, 543, 6, 4, 0, 0, 11, 0, },
/* O T */ {137, 65, 0, 0, 435, 19, 11, 9, 127, 5, 10, 14, 3, 57, 214, 11, 0, 30, 102, 371, 12, 16, 0, 0, 10, 0, },
/* O U */ {0, 1, 5, 2, 0, 0, 2, 0, 3, 0, 0, 9, 1, 13, 0, 1, 1, 55, 6, 32, 0, 5, 0, 0, 0, 1, },
/* O V */ {41, 11, 0, 17, 763, 11, 30, 6, 35, 21, 8, 11, 8, 58, 12, 5, 0, 10, 45, 6, 7, 5, 0, 0, 0, 0, },
/* O W */ {3, 5, 0, 0, 2, 0, 0, 1, 1, 0, 0, 6, 1, 7, 1, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, },
/* O X */ {0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 1, 0, },
/* O Y */ {8, 0, 0, 1, 2, 0, 0, 1, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, },
/* O Z */ {1, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 11, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, }},
/* P A */ {{235, 2, 3, 24, 15, 1, 31, 1, 2, 0, 116, 107, 12, 198, 0, 123, 1, 724, 236, 103, 24, 12, 0, 1, 2, 0, },
/* P B */ {5, 0, 0, 0, 7, 0, 0, 0, 1, 0, 0, 9, 0, 0, 3, 0, 0, 12, 0, 0, 5, 0, 0, 0, 21, 0, },
/* P C */ {0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* P D */ {21, 0, 0, 0, 8, 0, 0, 0, 4, 0, 0, 0, 0, 0, 1, 0, 0, 79, 0, 0, 1, 0, 0, 0, 7, 0, },
/* P E */ {25, 34, 3, 157, 19, 47, 24, 18, 99, 8, 198, 291, 28, 598, 13, 44, 0, 1004, 320, 309, 13, 23, 0, 1, 0, 0, },
/* P F */ {22, 0, 0, 0, 2, 0, 1, 0, 14, 0, 0, 4, 0, 0, 36, 0, 0, 11, 0, 0, 2, 0, 0, 0, 6, 0, },
/* P G */ {84, 0, 0, 0, 2, 0, 0, 0, 6, 24, 0, 3, 0, 0, 0, 0, 0, 3, 0, 0, 1, 0, 0, 0, 0, 0, },
/* P H */ {20, 0, 0, 0, 18, 0, 0, 0, 18, 1, 0, 0, 0, 0, 54, 0, 0, 1, 0, 0, 7, 1, 0, 0, 0, 0, },
/* P I */ {15, 3, 5, 25, 38, 6, 48, 4, 1, 0, 76, 311, 4, 236, 41, 24, 0, 184, 164, 92, 7, 7, 0, 0, 0, 3, },
/* P J */ {19, 0, 0, 0, 9, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 4, 0, 0, 0, 0, 0, },
/* P K */ {11, 0, 0, 0, 0, 0, 0, 0, 0, 16, 0, 7, 0, 0, 12, 0, 0, 7, 0, 0, 3, 3, 0, 0, 0, 0, },
/* P L */ {888, 0, 0, 0, 312, 0, 0, 0, 230, 0, 0, 0, 0, 0, 124, 0, 0, 0, 0, 0, 61, 0, 0, 0, 45, 0, },
/* P M */ {22, 0, 0, 0, 7, 0, 0, 0, 3, 0, 0, 0, 0, 0, 7, 0, 0, 0, 0, 0, 4, 0, 0, 0, 3, 0, },
/* P N */ {11, 0, 0, 0, 37, 0, 0, 0, 73, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, },
/* P O */ {0, 0, 1, 13, 184, 9, 10, 1, 4, 0, 28, 453, 17, 151, 6, 36, 0, 575, 293, 137, 1, 4, 1, 0, 0, 0, },
/* P P */ {121, 52, 1, 110, 700, 81, 116, 88, 54, 8, 47, 280, 33, 12, 122, 0, 0, 83, 200, 73, 9, 44, 0, 0, 1, 0, },
/* P Q */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* P R */ {269, 0, 0, 0, 621, 0, 0, 0, 431, 0, 0, 0, 0, 0, 1610, 1, 0, 0, 0, 0, 35, 1, 0, 0, 22, 0, },
/* P S */ {51, 42, 3, 23, 86, 65, 11, 20, 42, 53, 88, 62, 37, 9, 31, 44, 0, 27, 47, 99, 11, 30, 1, 0, 66, 0, },
/* P T */ {55, 2, 0, 0, 56, 3, 4, 0, 92, 1, 0, 2, 0, 1, 28, 1, 0, 21, 0, 0, 20, 1, 0, 0, 1, 0, },
/* P U */ {2, 42, 1, 20, 4, 2, 4, 0, 0, 0, 10, 84, 25, 216, 0, 7, 0, 51, 50, 45, 0, 0, 0, 0, 0, 0, },
/* P V */ {24, 0, 1, 0, 16, 0, 0, 0, 12, 0, 0, 0, 0, 0, 3, 0, 0, 1, 0, 0, 1, 0, 0, 0, 0, 0, },
/* P W */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* P X */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* P Y */ {0, 0, 0, 12, 0, 1, 2, 0, 0, 2, 1, 9, 0, 12, 1, 0, 0, 23, 4, 15, 0, 0, 0, 0, 0, 0, },
/* P Z */ {0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, }},
/* Q A */ {{0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, },
/* Q B */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* Q C */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* Q D */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* Q E */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* Q F */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* Q G */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* Q H */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* Q I */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* Q J */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* Q K */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* Q L */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* Q M */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* Q N */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* Q O */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* Q P */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* Q Q */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* Q R */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* Q S */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* Q T */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* Q U */ {4, 0, 0, 0, 8, 0, 0, 0, 10, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* Q V */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* Q W */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* Q X */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* Q Y */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* Q Z */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, }},
/* R A */ {{1042, 111, 18, 369, 54, 629, 245, 20, 37, 6, 496, 390, 747, 1135, 12, 251, 0, 84, 570, 691, 75, 324, 5, 1, 11, 4, },
/* R B */ {132, 0, 0, 0, 976, 0, 0, 0, 96, 6, 1, 32, 0, 0, 103, 0, 0, 156, 0, 0, 221, 0, 0, 0, 46, 0, },
/* R C */ {2, 0, 0, 0, 13, 0, 0, 2, 2, 0, 2, 0, 0, 0, 0, 0, 0, 2, 1, 1, 2, 0, 0, 0, 1, 0, },
/* R D */ {182, 97, 1, 30, 480, 51, 12, 29, 448, 1, 42, 50, 30, 170, 89, 14, 0, 115, 225, 30, 30, 35, 1, 0, 15, 0, },
/* R E */ {198, 122, 10, 717, 45, 292, 684, 71, 456, 15, 858, 418, 472, 1280, 55, 352, 0, 628, 1327, 1355, 50, 451, 1, 0, 3, 0, },
/* R F */ {169, 0, 0, 0, 83, 1, 0, 0, 58, 17, 0, 70, 0, 0, 280, 0, 0, 35, 1, 7, 36, 0, 0, 0, 16, 0, },
/* R G */ {299, 3, 3, 0, 368, 13, 4, 12, 169, 21, 10, 30, 10, 3, 42, 3, 0, 100, 41, 8, 32, 8, 1, 0, 4, 0, },
/* R H */ {205, 0, 0, 0, 190, 0, 0, 0, 21, 18, 0, 0, 0, 0, 242, 0, 0, 0, 0, 0, 45, 3, 0, 0, 7, 0, },
/* R I */ {255, 106, 19, 174, 494, 578, 332, 45, 12, 1, 645, 141, 181, 2633, 175, 114, 0, 13, 985, 352, 122, 428, 0, 4, 0, 3, },
/* R J */ {9, 0, 0, 0, 70, 0, 0, 0, 2, 0, 0, 0, 0, 0, 16, 0, 0, 0, 0, 0, 16, 0, 0, 0, 0, 0, },
/* R K */ {153, 8, 0, 4, 821, 1, 1, 4, 216, 63, 1, 112, 5, 79, 187, 2, 0, 61, 219, 52, 88, 32, 0, 0, 7, 0, },
/* R L */ {201, 0, 0, 1, 137, 0, 0, 0, 249, 1, 0, 0, 0, 0, 100, 0, 0, 0, 8, 0, 12, 0, 0, 0, 17, 0, },
/* R M */ {625, 32, 0, 5, 368, 11, 7, 11, 227, 5, 13, 16, 3, 0, 142, 8, 0, 7, 42, 19, 77, 6, 0, 0, 7, 0, },
/* R N */ {163, 62, 0, 25, 666, 14, 4, 23, 76, 0, 22, 18, 15, 6, 57, 11, 0, 8, 141, 15, 30, 17, 1, 0, 13, 0, },
/* R O */ {25, 197, 17, 410, 1453, 142, 378, 4, 25, 13, 146, 339, 395, 329, 4, 324, 2, 133, 652, 255, 3, 125, 3, 2, 5, 0, },
/* R P */ {69, 0, 0, 0, 100, 0, 0, 0, 20, 1, 0, 70, 0, 0, 56, 0, 0, 94, 38, 2, 25, 0, 0, 0, 2, 0, },
/* R Q */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, },
/* R R */ {169, 4, 0, 4, 519, 8, 8, 3, 137, 0, 3, 8, 1, 1, 93, 2, 0, 0, 26, 1, 11, 11, 0, 0, 6, 0, },
/* R S */ {149, 42, 4, 56, 310, 51, 29, 23, 249, 114, 806, 152, 121, 35, 366, 139, 0, 23, 67, 621, 36, 144, 0, 0, 94, 1, },
/* R T */ {159, 36, 0, 7, 610, 42, 13, 34, 467, 20, 32, 35, 21, 36, 171, 20, 0, 173, 226, 21, 59, 32, 0, 0, 34, 3, },
/* R U */ {12, 34, 3, 135, 56, 11, 33, 9, 22, 2, 703, 97, 115, 451, 2, 259, 0, 37, 223, 315, 1, 47, 0, 2, 0, 1, },
/* R V */ {216, 2, 0, 0, 461, 2, 0, 0, 304, 10, 1, 2, 4, 0, 117, 0, 0, 6, 14, 2, 4, 0, 0, 0, 0, 0, },
/* R W */ {8, 0, 0, 0, 2, 0, 0, 0, 7, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, },
/* R X */ {0, 0, 0, 0, 1, 0, 0, 0, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* R Y */ {0, 2, 0, 59, 7, 6, 157, 0, 0, 0, 326, 49, 8, 43, 7, 47, 0, 13, 126, 145, 0, 1, 0, 0, 0, 0, },
/* R Z */ {1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, }},
/* S A */ {{176, 36, 3, 43, 114, 35, 98, 5, 7, 2, 356, 467, 874, 505, 0, 32, 0, 270, 205, 231, 98, 179, 1, 0, 3, 0, },
/* S B */ {152, 0, 0, 0, 422, 0, 0, 0, 72, 6, 0, 47, 0, 1, 134, 0, 0, 158, 2, 0, 67, 0, 0, 0, 109, 0, },
/* S C */ {7, 0, 0, 0, 64, 0, 0, 27, 23, 0, 0, 0, 0, 0, 18, 0, 0, 4, 0, 0, 2, 0, 0, 0, 0, 0, },
/* S D */ {221, 0, 0, 0, 118, 0, 0, 0, 94, 2, 0, 0, 0, 0, 82, 0, 0, 71, 0, 0, 4, 0, 0, 0, 48, 0, },
/* S E */ {66, 127, 4, 146, 53, 145, 112, 45, 199, 4, 497, 943, 263, 1191, 51, 164, 0, 1588, 737, 668, 76, 123, 0, 17, 4, 0, },
/* S F */ {247, 0, 0, 0, 122, 0, 0, 0, 94, 54, 0, 65, 0, 0, 704, 0, 0, 118, 0, 1, 103, 0, 0, 0, 20, 0, },
/* S G */ {75, 0, 0, 0, 38, 0, 0, 0, 34, 32, 0, 14, 1, 0, 18, 0, 0, 187, 0, 0, 23, 0, 0, 0, 3, 0, },
/* S H */ {138, 1, 0, 0, 133, 0, 0, 0, 65, 31, 0, 0, 2, 1, 135, 0, 0, 0, 0, 2, 59, 2, 0, 0, 20, 0, },
/* S I */ {393, 30, 6, 357, 136, 68, 218, 1, 1, 0, 598, 186, 182, 668, 57, 93, 0, 64, 375, 323, 16, 136, 1, 0, 0, 0, },
/* S J */ {156, 4, 0, 0, 953, 3, 0, 2, 32, 0, 0, 0, 3, 1, 3498, 6, 0, 1, 2, 3, 178, 0, 0, 0, 8, 0, },
/* S K */ {1596, 8, 0, 4, 1034, 12, 0, 6, 1068, 602, 8, 108, 11, 126, 1450, 9, 0, 1045, 17, 16, 461, 100, 0, 0, 319, 0, },
/* S L */ {693, 0, 0, 0, 513, 0, 0, 0, 391, 0, 0, 0, 0, 0, 321, 0, 0, 0, 0, 0, 223, 0, 0, 0, 46, 0, },
/* S M */ {764, 0, 0, 0, 609, 0, 0, 0, 233, 1, 0, 1, 0, 0, 273, 0, 0, 0, 2, 0, 109, 0, 0, 0, 44, 0, },
/* S N */ {130, 0, 0, 0, 202, 0, 0, 0, 594, 0, 0, 0, 0, 0, 199, 0, 0, 0, 0, 0, 72, 0, 0, 0, 21, 0, },
/* S O */ {5, 14, 1, 21, 891, 62, 21, 5, 5, 0, 50, 261, 456, 351, 1, 224, 0, 390, 158, 42, 4, 104, 0, 0, 3, 0, },
/* S P */ {331, 0, 0, 1, 884, 0, 0, 0, 476, 10, 0, 286, 1, 0, 655, 0, 0, 850, 13, 0, 101, 0, 0, 0, 29, 0, },
/* S Q */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, },
/* S R */ {148, 1, 0, 0, 405, 0, 0, 0, 41, 0, 0, 0, 0, 0, 110, 0, 0, 0, 2, 0, 64, 0, 0, 0, 9, 0, },
/* S S */ {266, 40, 5, 19, 1194, 58, 19, 29, 303, 110, 307, 60, 33, 9, 150, 109, 0, 34, 1, 563, 115, 56, 0, 0, 151, 0, },
/* S T */ {1983, 111, 1, 25, 3220, 106, 44, 47, 1739, 176, 71, 106, 80, 230, 1347, 45, 0, 1954, 122, 41, 505, 62, 0, 0, 678, 0, },
/* S U */ {17, 63, 0, 5, 10, 14, 33, 2, 10, 1, 78, 170, 72, 183, 2, 114, 0, 223, 57, 229, 0, 5, 0, 0, 0, 0, },
/* S V */ {546, 0, 0, 0, 460, 0, 0, 0, 375, 0, 0, 0, 0, 0, 106, 0, 0, 1, 2, 1, 29, 0, 0, 0, 2, 0, },
/* S W */ {10, 0, 0, 0, 3, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* S X */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* S Y */ {0, 1, 1, 30, 5, 4, 6, 0, 1, 0, 367, 53, 64, 383, 0, 2, 0, 57, 365, 25, 0, 6, 0, 0, 0, 0, },
/* S Z */ {2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, }},
/* T A */ {{308, 314, 10, 192, 171, 85, 84, 12, 30, 3, 704, 1057, 183, 911, 9, 132, 0, 327, 503, 528, 88, 166, 1, 6, 2, 0, },
/* T B */ {150, 0, 1, 0, 116, 0, 0, 0, 41, 1, 0, 41, 0, 0, 73, 0, 0, 73, 1, 0, 20, 0, 0, 0, 75, 0, },
/* T C */ {1, 0, 0, 0, 5, 0, 0, 10, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* T D */ {220, 1, 0, 0, 28, 0, 0, 0, 19, 0, 0, 0, 0, 0, 8, 0, 0, 21, 0, 0, 4, 0, 0, 0, 9, 0, },
/* T E */ {197, 174, 8, 309, 33, 174, 420, 67, 306, 14, 825, 826, 838, 942, 127, 154, 0, 3334, 510, 1071, 30, 136, 2, 5, 5, 0, },
/* T F */ {77, 0, 0, 0, 65, 0, 0, 0, 55, 14, 0, 34, 0, 0, 292, 0, 0, 39, 0, 0, 31, 0, 0, 0, 12, 0, },
/* T G */ {77, 0, 0, 0, 17, 0, 0, 0, 90, 47, 0, 11, 0, 0, 9, 0, 0, 63, 0, 0, 7, 0, 0, 0, 4, 0, },
/* T H */ {85, 0, 0, 0, 107, 0, 0, 0, 20, 12, 0, 0, 0, 0, 65, 0, 0, 4, 1, 0, 36, 10, 0, 0, 3, 0, },
/* T I */ {99, 22, 8, 680, 69, 105, 460, 9, 5, 2, 650, 1424, 241, 767, 29, 107, 0, 30, 811, 227, 27, 493, 0, 0, 0, 0, },
/* T J */ {36, 0, 0, 0, 354, 0, 0, 0, 0, 0, 0, 0, 0, 0, 21, 0, 0, 0, 0, 0, 43, 0, 0, 0, 0, 0, },
/* T K */ {86, 0, 0, 0, 4, 0, 0, 0, 19, 34, 0, 36, 0, 6, 140, 0, 0, 28, 0, 0, 26, 15, 0, 0, 4, 0, },
/* T L */ {166, 0, 0, 0, 179, 1, 1, 0, 136, 0, 0, 0, 0, 0, 88, 0, 0, 0, 0, 0, 12, 0, 0, 0, 9, 0, },
/* T M */ {127, 0, 0, 0, 104, 0, 0, 0, 35, 1, 0, 0, 0, 0, 58, 0, 0, 0, 0, 0, 22, 0, 0, 0, 4, 0, },
/* T N */ {120, 1, 0, 0, 178, 3, 0, 2, 663, 0, 0, 0, 0, 0, 31, 0, 0, 1, 0, 1, 16, 0, 0, 0, 18, 0, },
/* T O */ {26, 51, 5, 141, 1080, 157, 137, 7, 11, 1, 139, 296, 296, 224, 7, 247, 0, 1559, 49, 87, 14, 55, 1, 1, 1, 0, },
/* T P */ {63, 0, 0, 0, 28, 0, 0, 0, 10, 0, 0, 32, 0, 0, 35, 0, 0, 98, 0, 0, 24, 0, 0, 0, 2, 0, },
/* T Q */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* T R */ {1368, 0, 0, 1, 1177, 0, 0, 1, 792, 0, 0, 2, 0, 0, 993, 1, 0, 0, 0, 0, 386, 0, 0, 0, 371, 0, },
/* T S */ {208, 138, 4, 71, 217, 215, 57, 63, 138, 67, 357, 162, 148, 46, 124, 211, 0, 96, 215, 500, 60, 90, 2, 0, 42, 0, },
/* T T */ {199, 60, 1, 15, 1875, 106, 20, 77, 379, 16, 61, 91, 42, 9, 105, 59, 0, 110, 428, 0, 35, 55, 0, 0, 24, 0, },
/* T U */ {97, 25, 2, 250, 112, 9, 16, 0, 12, 0, 25, 39, 66, 157, 5, 17, 0, 802, 183, 130, 2, 12, 0, 0, 0, 0, },
/* T V */ {207, 0, 0, 0, 231, 0, 0, 0, 338, 0, 0, 0, 0, 0, 11, 0, 0, 0, 0, 0, 8, 0, 0, 0, 0, 0, },
/* T W */ {2, 0, 0, 0, 4, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* T X */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* T Y */ {1, 2, 1, 40, 2, 6, 19, 0, 1, 0, 121, 26, 13, 63, 0, 126, 0, 595, 24, 7, 0, 37, 0, 0, 0, 0, },
/* T Z */ {0, 0, 0, 0, 4, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, }},
/* U A */ {{7, 0, 0, 4, 0, 0, 2, 1, 0, 0, 4, 53, 0, 12, 0, 0, 0, 12, 79, 3, 0, 16, 1, 0, 4, 0, },
/* U B */ {33, 114, 0, 1, 63, 0, 0, 1, 50, 6, 1, 71, 2, 3, 7, 0, 0, 10, 26, 6, 7, 2, 0, 0, 1, 0, },
/* U C */ {0, 0, 0, 0, 2, 0, 0, 8, 3, 0, 7, 1, 0, 0, 1, 0, 0, 0, 0, 0, 1, 0, 1, 0, 0, 0, },
/* U D */ {25, 10, 0, 227, 166, 11, 1, 3, 203, 0, 8, 9, 2, 5, 19, 2, 0, 15, 199, 7, 4, 4, 0, 0, 3, 0, },
/* U E */ {6, 7, 0, 3, 3, 17, 9, 9, 0, 1, 6, 60, 3, 29, 2, 6, 0, 87, 51, 20, 2, 4, 0, 0, 0, 2, },
/* U F */ {4, 0, 0, 0, 8, 45, 0, 0, 5, 3, 0, 10, 0, 4, 39, 0, 0, 9, 17, 154, 4, 0, 0, 0, 2, 0, },
/* U G */ {23, 4, 0, 10, 66, 1, 95, 2, 12, 7, 2, 160, 4, 22, 9, 2, 0, 11, 20, 5, 20, 0, 0, 0, 0, 0, },
/* U H */ {9, 0, 0, 0, 12, 1, 0, 0, 2, 1, 0, 0, 0, 0, 6, 0, 0, 3, 0, 0, 3, 0, 0, 0, 4, 0, },
/* U I */ {0, 0, 4, 25, 1, 0, 0, 0, 0, 1, 0, 3, 5, 27, 0, 0, 0, 1, 29, 31, 0, 1, 0, 0, 0, 0, },
/* U J */ {3, 0, 0, 0, 5, 0, 0, 0, 1, 0, 0, 0, 0, 0, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* U K */ {19, 1, 0, 31, 300, 1, 0, 3, 2, 5, 200, 24, 3, 31, 16, 0, 0, 14, 552, 376, 6, 6, 0, 0, 0, 0, },
/* U L */ {222, 12, 1, 62, 473, 17, 17, 3, 127, 22, 36, 549, 10, 5, 29, 19, 0, 8, 78, 349, 10, 70, 0, 0, 51, 0, },
/* U M */ {30, 21, 1, 4, 217, 23, 4, 7, 71, 0, 13, 27, 186, 5, 24, 108, 0, 9, 186, 4, 12, 6, 0, 0, 0, 0, },
/* U N */ {46, 7, 11, 953, 106, 5, 302, 5, 195, 1, 431, 3, 0, 762, 14, 0, 0, 7, 218, 46, 1, 3, 0, 0, 2, 0, },
/* U O */ {0, 1, 0, 1, 6, 0, 0, 0, 0, 0, 0, 1, 4, 0, 0, 11, 0, 17, 5, 0, 0, 8, 0, 0, 0, 0, },
/* U P */ {19, 3, 0, 2, 80, 2, 0, 1, 9, 0, 1, 15, 0, 5, 10, 322, 0, 11, 27, 7, 6, 2, 0, 0, 0, 0, },
/* U Q */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, },
/* U R */ {122, 50, 1, 78, 138, 51, 72, 15, 146, 3, 61, 29, 38, 91, 81, 52, 0, 111, 402, 96, 60, 84, 0, 0, 14, 0, },
/* U S */ {38, 44, 2, 17, 281, 30, 10, 46, 159, 185, 183, 57, 28, 14, 32, 38, 0, 15, 196, 443, 20, 23, 0, 0, 3, 1, },
/* U T */ {86, 93, 1, 205, 276, 87, 120, 22, 149, 4, 54, 81, 23, 73, 145, 25, 0, 84, 352, 377, 20, 344, 0, 0, 5, 1, },
/* U U */ {0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 10, 2, 0, 0, 0, 0, 0, 8, 0, 0, 0, 0, 0, 0, },
/* U V */ {13, 0, 0, 3, 90, 3, 1, 0, 8, 1, 0, 4, 0, 0, 8, 0, 0, 2, 9, 4, 2, 1, 0, 0, 0, 0, },
/* U W */ {3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* U X */ {1, 0, 0, 0, 5, 0, 0, 2, 2, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* U Y */ {1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* U Z */ {0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, }},
/* V A */ {{413, 6, 0, 47, 293, 8, 13, 0, 7, 1, 174, 583, 20, 596, 0, 9, 0, 837, 197, 174, 3, 6, 0, 0, 0, 0, },
/* V B */ {15, 0, 0, 0, 44, 0, 0, 0, 19, 2, 0, 44, 0, 0, 8, 0, 0, 44, 0, 0, 7, 0, 0, 0, 8, 0, },
/* V C */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* V D */ {18, 0, 0, 0, 222, 0, 0, 0, 10, 1, 0, 0, 0, 0, 14, 0, 0, 18, 0, 0, 2, 2, 0, 0, 13, 0, },
/* V E */ {28, 52, 2, 328, 10, 41, 347, 22, 347, 3, 336, 626, 51, 565, 18, 42, 0, 2115, 290, 266, 10, 71, 0, 0, 0, 0, },
/* V F */ {41, 0, 0, 0, 15, 0, 0, 0, 11, 5, 0, 7, 0, 1, 44, 0, 0, 9, 1, 0, 8, 0, 0, 0, 3, 0, },
/* V G */ {44, 0, 0, 0, 1, 0, 0, 0, 155, 17, 0, 6, 0, 0, 4, 0, 0, 31, 1, 0, 9, 0, 0, 0, 1, 0, },
/* V H */ {12, 0, 0, 0, 67, 1, 0, 0, 0, 10, 0, 0, 0, 0, 33, 0, 0, 0, 0, 0, 9, 1, 0, 0, 1, 0, },
/* V I */ {27, 8, 68, 174, 41, 10, 62, 3, 2, 0, 475, 331, 24, 859, 5, 13, 0, 270, 806, 369, 1, 30, 0, 0, 0, 0, },
/* V J */ {0, 0, 0, 0, 30, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 11, 0, 0, 0, 0, 0, },
/* V K */ {25, 0, 0, 0, 0, 0, 0, 0, 7, 18, 0, 17, 0, 2, 37, 0, 0, 19, 0, 0, 9, 5, 0, 0, 1, 0, },
/* V L */ {43, 0, 0, 0, 110, 0, 0, 1, 30, 0, 0, 0, 0, 0, 59, 0, 0, 0, 14, 0, 10, 0, 0, 0, 16, 0, },
/* V M */ {35, 0, 0, 0, 20, 0, 0, 0, 6, 0, 0, 0, 0, 0, 29, 0, 0, 0, 0, 0, 1, 0, 0, 0, 3, 0, },
/* V N */ {16, 1, 0, 4, 233, 3, 11, 2, 71, 0, 1, 6, 0, 1, 4, 1, 0, 0, 23, 11, 3, 1, 0, 0, 0, 0, },
/* V O */ {81, 0, 0, 3, 93, 4, 70, 0, 8, 0, 154, 188, 13, 27, 1, 16, 0, 96, 11, 64, 2, 22, 0, 1, 3, 0, },
/* V P */ {12, 0, 0, 0, 7, 0, 0, 0, 3, 0, 0, 10, 0, 0, 2, 0, 0, 17, 0, 0, 5, 0, 0, 0, 0, 0, },
/* V Q */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* V R */ {57, 0, 0, 0, 99, 0, 0, 0, 51, 0, 1, 0, 0, 0, 26, 0, 0, 0, 0, 0, 7, 0, 0, 0, 1, 0, },
/* V S */ {32, 7, 0, 4, 44, 23, 6, 4, 19, 7, 129, 49, 19, 36, 22, 45, 0, 8, 20, 138, 11, 20, 0, 0, 12, 0, },
/* V T */ {112, 0, 0, 0, 14, 0, 0, 0, 15, 2, 0, 4, 0, 0, 9, 0, 0, 26, 1, 0, 2, 2, 0, 0, 12, 0, },
/* V U */ {2, 0, 0, 1, 2, 0, 1, 0, 0, 0, 1, 36, 2, 27, 1, 0, 0, 44, 0, 10, 0, 1, 0, 0, 0, 0, },
/* V V */ {13, 0, 0, 0, 37, 0, 0, 0, 35, 0, 0, 0, 0, 0, 3, 0, 0, 0, 1, 0, 1, 0, 0, 0, 0, 0, },
/* V W */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* V X */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* V Y */ {0, 0, 0, 0, 3, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 3, 0, 0, 0, 0, 0, 0, },
/* V Z */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, }},
/* W A */ {{0, 0, 0, 0, 0, 0, 3, 1, 4, 0, 1, 8, 3, 10, 0, 0, 0, 10, 1, 10, 0, 0, 0, 0, 5, 3, },
/* W B */ {2, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, },
/* W C */ {1, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* W D */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, },
/* W E */ {2, 0, 1, 0, 8, 1, 1, 0, 2, 0, 0, 6, 0, 1, 0, 0, 0, 5, 7, 1, 1, 0, 0, 0, 0, 0, },
/* W F */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, },
/* W G */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* W H */ {0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* W I */ {0, 0, 4, 2, 10, 1, 3, 0, 1, 0, 0, 10, 2, 10, 0, 0, 0, 1, 6, 2, 0, 0, 0, 0, 0, 0, },
/* W J */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* W K */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* W L */ {0, 0, 0, 0, 6, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* W M */ {1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* W N */ {0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, },
/* W O */ {0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 1, 0, 0, 4, 0, 0, 1, 0, 0, 0, 0, 0, },
/* W P */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, },
/* W Q */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* W R */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* W S */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, },
/* W T */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* W U */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, },
/* W V */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* W W */ {0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* W X */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* W Y */ {0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, },
/* W Z */ {0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, }},
/* X A */ {{0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 6, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, },
/* X B */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* X C */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* X D */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* X E */ {0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 2, 4, 1, 0, 0, 0, 7, 1, 0, 0, 0, 0, 0, 0, 0, },
/* X F */ {0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* X G */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* X H */ {2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, },
/* X I */ {0, 1, 3, 1, 0, 2, 0, 0, 0, 0, 1, 1, 0, 2, 1, 0, 0, 0, 5, 2, 0, 0, 0, 0, 0, 0, },
/* X J */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* X K */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* X L */ {1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* X M */ {0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* X N */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* X O */ {0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, },
/* X P */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, },
/* X Q */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* X R */ {0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* X S */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 1, 0, },
/* X T */ {0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 1, 0, 0, 0, 0, 0, },
/* X U */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, },
/* X V */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* X W */ {0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* X X */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* X Y */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 8, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* X Z */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, }},
/* Y A */ {{3, 1, 2, 0, 2, 1, 0, 0, 0, 0, 11, 10, 0, 34, 1, 0, 0, 5, 1, 1, 0, 4, 0, 0, 0, 0, },
/* Y B */ {16, 2, 0, 11, 19, 0, 0, 0, 4, 2, 0, 2, 0, 0, 13, 0, 0, 16, 1, 0, 8, 0, 0, 0, 8, 0, },
/* Y C */ {0, 0, 0, 0, 2, 0, 0, 3, 3, 0, 0, 0, 0, 0, 1, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, },
/* Y D */ {13, 9, 0, 36, 125, 8, 4, 4, 30, 0, 8, 6, 7, 20, 8, 6, 0, 47, 15, 4, 2, 3, 0, 0, 1, 0, },
/* Y E */ {2, 6, 0, 4, 2, 2, 1, 2, 0, 0, 7, 42, 13, 53, 0, 1, 0, 37, 22, 22, 1, 2, 0, 0, 0, 0, },
/* Y F */ {5, 0, 0, 0, 10, 5, 0, 0, 10, 12, 0, 4, 0, 0, 31, 0, 0, 11, 1, 0, 4, 0, 0, 0, 1, 0, },
/* Y G */ {13, 0, 0, 192, 55, 0, 386, 0, 22, 1, 0, 10, 1, 85, 5, 0, 0, 9, 6, 3, 2, 1, 0, 0, 0, 0, },
/* Y H */ {16, 0, 0, 0, 26, 0, 0, 0, 3, 0, 0, 0, 0, 0, 7, 0, 0, 1, 0, 0, 4, 1, 0, 0, 0, 0, },
/* Y I */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 32, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, },
/* Y J */ {2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, },
/* Y K */ {11, 2, 0, 52, 182, 2, 2, 1, 26, 8, 559, 59, 2, 24, 59, 1, 0, 5, 7, 102, 4, 4, 0, 0, 0, 0, },
/* Y L */ {31, 5, 0, 66, 49, 3, 3, 4, 20, 0, 108, 171, 1, 3, 25, 2, 0, 1, 22, 74, 0, 7, 0, 0, 2, 0, },
/* Y M */ {14, 28, 0, 0, 40, 12, 0, 0, 12, 0, 0, 1, 5, 29, 14, 31, 0, 12, 4, 2, 3, 0, 0, 0, 1, 0, },
/* Y N */ {38, 1, 0, 146, 47, 3, 105, 0, 69, 4, 43, 18, 2, 56, 35, 0, 0, 2, 127, 81, 0, 2, 0, 0, 0, 0, },
/* Y O */ {0, 0, 0, 0, 0, 0, 4, 0, 0, 0, 3, 4, 4, 7, 0, 9, 0, 10, 0, 1, 3, 0, 0, 0, 0, 0, },
/* Y P */ {7, 2, 0, 3, 171, 7, 1, 2, 13, 0, 0, 21, 0, 10, 29, 27, 0, 15, 8, 35, 2, 4, 0, 0, 0, 0, },
/* Y Q */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* Y R */ {53, 7, 0, 33, 446, 7, 2, 8, 130, 5, 230, 16, 20, 5, 16, 8, 0, 24, 46, 52, 10, 12, 0, 0, 1, 0, },
/* Y S */ {29, 11, 0, 1, 202, 4, 6, 1, 77, 9, 76, 15, 3, 59, 12, 10, 0, 6, 129, 611, 13, 10, 1, 0, 4, 0, },
/* Y T */ {7, 1, 0, 2, 304, 4, 0, 2, 67, 2, 2, 4, 14, 33, 13, 1, 0, 33, 12, 386, 5, 1, 0, 0, 1, 0, },
/* Y U */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 9, 0, 0, 0, 0, 0, 0, },
/* Y V */ {22, 1, 0, 4, 59, 1, 0, 0, 20, 1, 0, 0, 0, 5, 2, 0, 0, 1, 1, 1, 2, 0, 0, 0, 0, 0, },
/* Y W */ {0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* Y X */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* Y Y */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* Y Z */ {0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, }},
/* Z A */ {{0, 1, 1, 0, 0, 0, 1, 0, 3, 0, 0, 0, 2, 7, 0, 0, 0, 3, 1, 0, 0, 1, 1, 0, 0, 0, },
/* Z B */ {2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* Z C */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* Z D */ {1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* Z E */ {5, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 10, 1, 1, 0, 6, 0, 0, 1, 1, 0, 0, 0, 0, },
/* Z F */ {0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* Z G */ {0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* Z H */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* Z I */ {2, 2, 0, 1, 0, 2, 1, 1, 0, 1, 0, 4, 3, 3, 0, 1, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, },
/* Z J */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* Z K */ {2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* Z L */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, },
/* Z M */ {1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, },
/* Z N */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* Z O */ {0, 0, 0, 0, 0, 4, 0, 0, 4, 0, 0, 3, 0, 12, 10, 1, 0, 5, 2, 0, 0, 0, 0, 0, 0, 0, },
/* Z P */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, },
/* Z Q */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* Z R */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* Z S */ {0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* Z T */ {1, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* Z U */ {0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, },
/* Z V */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* Z W */ {0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* Z X */ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* Z Y */ {0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 2, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, },
/* Z Z */ {5, 2, 0, 0, 3, 1, 1, 0, 3, 0, 2, 2, 2, 0, 4, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, }
}};

  static void fill(GpwData xx) {
    int c1,c2,c3;
      for (c1=0; c1 < 13; c1++) {
	for (c2=0; c2 < 26; c2++) {
	  for (c3=0; c3 < 26; c3++) {
	    xx.set(c1+13, c2, c3, tris2[c1][c2][c3]);
	  } // for c3
	} // for c2
      } // for c1
  } // fill()

} // GpwDataInit1
